pub struct MovingWindow<T: MovingWindowValue> { /* private fields */ }Expand description
A moving window that maintains the last N values of type T and calculates
their arithmetic mean. All values in the window have equal weight and the
oldest value is dropped when the window exceeds its configured capacity.
Implementations
Sourceimpl<T: MovingWindowValue> MovingWindow<T>
impl<T: MovingWindowValue> MovingWindow<T>
Sourcepub fn new(init_value: T, max_size: usize) -> Self
pub fn new(init_value: T, max_size: usize) -> Self
Creates a new MovingWindow with the specified maximum size and an
init_value. The provided max_size must be greater than 0.
Sourcepub fn add_value(&mut self, value: T)
pub fn add_value(&mut self, value: T)
Adds a new value to the window. If the window is at capacity, the oldest value is removed before adding the new value.
Sourcepub fn get(&self) -> T
pub fn get(&self) -> T
Get the current average of all values in the window. Returns the value’s zero if the window is empty.
pub fn is_empty(&self) -> bool